# doks

## 1.8.1

### Patch Changes

- [#1372](https://github.com/thuliteio/doks/pull/1372) [`bb44bf8`](https://github.com/thuliteio/doks/commit/bb44bf84e046d4dbd03ec6ef6b1051db5f6e80b1) Thanks [@h-enk](https://github.com/h-enk)! - Fix layouts mounting order

## 1.8.0

### Minor Changes

- [#1369](https://github.com/thuliteio/doks/pull/1369) [`d03e363`](https://github.com/thuliteio/doks/commit/d03e3634a85f26bcd3c71e99b829d5258fd25c60) Thanks [@h-enk](https://github.com/h-enk)! - Update for new template system in Hugo v0.146.0

- [#1356](https://github.com/thuliteio/doks/pull/1356) [`6f457a6`](https://github.com/thuliteio/doks/commit/6f457a6da7d6254fa0315e39b166423a4c389e90) Thanks [@LemonDouble](https://github.com/LemonDouble)! - fix : Fixes the issue of layout breaking due to changes in layout priority in Hugo 0.146.0

### Patch Changes

- [#1303](https://github.com/thuliteio/doks/pull/1303) [`f13c768`](https://github.com/thuliteio/doks/commit/f13c768d43cca497c77a6e7b4995f2c0cfc6b962) Thanks [@AndiKod](https://github.com/AndiKod)! - Tiny typo "by by" => "by"

## 1.7.0

### Minor Changes

- [#1276](https://github.com/thuliteio/doks/pull/1276) [`b3145cd`](https://github.com/thuliteio/doks/commit/b3145cd021a9ab6ee244f3ad8aa38d8b3aa1c4a5) Thanks [@h-enk](https://github.com/h-enk)! - Update for migration from Hyas to Thulite

### Patch Changes

- [#1266](https://github.com/thuliteio/doks/pull/1266) [`009064a`](https://github.com/thuliteio/doks/commit/009064ad81d018521992ea2b6451b0906a02a1a0) Thanks [@l-zeuch](https://github.com/l-zeuch)! - Allow custom kroki host

- [#1256](https://github.com/thuliteio/doks/pull/1256) [`5d475ea`](https://github.com/thuliteio/doks/commit/5d475ead4f845afe68c370734ca47365b81e2024) Thanks [@Rancho-rachit](https://github.com/Rancho-rachit)! - Added LinkedIn Social

- [#1268](https://github.com/thuliteio/doks/pull/1268) [`7608454`](https://github.com/thuliteio/doks/commit/76084541c4d3c95f22a343f4dc538325088fba68) Thanks [@h-enk](https://github.com/h-enk)! - Add CodeSandbox support

## 1.6.2

### Patch Changes

- [#1230](https://github.com/gethyas/doks/pull/1230) [`25f55a3`](https://github.com/gethyas/doks/commit/25f55a37fa4162b7546d6ded9b449434e4965164) Thanks [@h-enk](https://github.com/h-enk)! - Install prettier and vite as devDependencies

## 1.6.1

### Patch Changes

- [#1229](https://github.com/gethyas/doks/pull/1229) [`7666ab6`](https://github.com/gethyas/doks/commit/7666ab62a9b04f0508530dfb8c7f5f7c6db0f966) Thanks [@h-enk](https://github.com/h-enk)! - Add gethyas dependency

## 1.6.0

### Minor Changes

- [#1228](https://github.com/gethyas/doks/pull/1228) [`4be4a68`](https://github.com/gethyas/doks/commit/4be4a689619b49f62df4c65024d3e865c1ead99e) Thanks [@h-enk](https://github.com/h-enk)! - Update dependencies to latest versions

## 1.5.0

### Minor Changes

- [#1226](https://github.com/gethyas/doks/pull/1226) [`664063e`](https://github.com/gethyas/doks/commit/664063eb6a02d24a3fceb61ea9ed8df589a11033) Thanks [@h-enk](https://github.com/h-enk)! - Update for new Hyas setup
